<?php
/**
 * @file
 * Contains functions handling views integration.
 */

/**
 * Implementation of hook_views_handlers().
 */
function rrdtool_cck_views_handlers() {
  return array(
    'info' => array(
      'path' => drupal_get_path('module', 'rrdtool_cck') .'/views',
    ),
    'handlers' => array(
      'rrdtool_cck_views_handler_field_startend' => array(
        'parent' => 'content_handler_field',
      ),
     'rrdtool_cck_views_handler_field_startend_multiple' => array(
        'parent' => 'rrdtool_cck_views_handler_field_startend',
      ),
      'rrdtool_cck_views_handler_filter_refresh' => array(
        'parent' => 'views_handler_filter_string',
      ),
      'rrdtool_cck_views_handler_filter_startend' => array(
        'parent' => 'views_handler_filter_string',
      ),
    ),
  );
}

/**
 * Return CCK Views data for the link_field_settings($op == 'views data').
 */
function rrdtool_cck_views_content_field_data($field) {
  // Build the automatic views data provided for us by CCK.
  $data = content_views_field_views_data($field);
  $db_info = content_database_info($field);
  $table_alias = content_views_tablename($field);
  $field_types = _content_field_types();


  // Build out additional Views filter for the link "startend" pseudo field.
  $data[$table_alias][$field['field_name'] .'_startend'] = array(
    'group' => t('RRD'),
    'title' => t('@label start/end', array('@label' => t($field_types[$field['type']]['label']))) .': '. t($field['widget']['label']) .' ('. $field['field_name'] .')',
    'help' =>  t('Provides a widget that you can use to chose start and end time. Use with the "no form" field formatter.'),
    'filter' => array(
      'field' => $db_info['columns']['time_offset']['column'],
      'title' => t('@label start/end', array('@label' => t($field_types[$field['type']]['label']))) .': '. t($field['widget']['label']),
      'tablename' => $db_info['table'],
      'handler' => 'rrdtool_cck_views_handler_filter_startend',
      'additional fields' => array(),
      'content_field_name' => $field['field_name'],
      'allow_empty' => TRUE,
    ),
  );

  // Build out additional Views filter for the link "refresh" pseudo field.
  $data[$table_alias][$field['field_name'] .'_refresh'] = array(
    'group' => t('RRD'),
    'title' => t('@label refresh', array('@label' => t($field_types[$field['type']]['label']))) .': '. t($field['widget']['label']) .' ('. $field['field_name'] .')',
    'help' =>  t('Provides a widget that you can use to chose the refresh rate.'),
    'filter' => array(
      'field' => $db_info['columns']['time_offset']['column'],
      'title' => t('@label refresh', array('@label' => t($field_types[$field['type']]['label']))) .': '. t($field['widget']['label']),
      'tablename' => $db_info['table'],
      'handler' => 'rrdtool_cck_views_handler_filter_refresh',
      'additional fields' => array(),
      'content_field_name' => $field['field_name'],
      'allow_empty' => TRUE,
    ),
  );

  // We need to use our own handler in order to pass the used view into the
  // formatter
  foreach (array('', '_external') as $external) {
    if (isset($data[$table_alias][$field['field_name'] ."_rrdtool_file$external"])) {
      switch ($data[$table_alias][$field['field_name'] ."_rrdtool_file$external"]['field']['handler']) {
        case 'content_handler_field_multiple':
          $data[$table_alias][$field['field_name'] ."_rrdtool_file$external"]['field']['handler'] = 'rrdtool_cck_views_handler_field_startend_multiple';
          break;
        case 'content_handler_field':
          $data[$table_alias][$field['field_name'] ."_rrdtool_file$external"]['field']['handler'] = 'rrdtool_cck_views_handler_field_startend';
          break;
      }
    }
  }

  return $data;
}