<?php

/**
 * @file
 * Contains filter handler for adding a start/end widget for rrdtool graphs with views.
 */

/**
 * Filter handler for adding start/end widget for x-axis.
 */
class rrdtool_cck_views_handler_filter_startend extends views_handler_filter_string {

  /**
   * Set defaults for the filter options.
   */
  function option_definition() {
    $options = parent::option_definition();
    $options['value'] = array(
      'contains' => array(
        'start' => array('default' => '10 minutes'),
        'end' => array('default' => 'now'),
      ),
    );

    return $options;
  }

  function operators() {
    $operators = array(
    );

    return $operators;
  }

  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);

    $form['time_options'] = array(
      '#type' => 'textarea',
      '#title' => t('Time options'),
      '#default_value' => isset($this->options['time_options']) ? $this->options['time_options'] : "5minutes|5 minutes ago\r\n10minutes|10 minutes ago\r\n30minutes|30 minutes ago\r\n1hour|1 hour ago\r\n6hours|6 hours ago\r\n12hours|12 hours ago\r\n1day|24 hours ago\r\n1week|1 week ago\r\n1month|1 month ago\r\n3months|3 months ago\r\n6months|6 months ago\r\n1y|1 year",
      '#description' => t('Add options that can be used to change the time axis of the graphs. One option per line, the format is key|value. The value is displayed to the user, the key passed to RRDtool. The format for the key needs to be a format that RRDtool understands. See <a href="!url">man rrdfetch</a> for examples. A "-" sign will be prefixed before passing to RRDtool.', array('!url' => 'http://oss.oetiker.ch/rrdtool/doc/rrdfetch.en.html')),
    );
  }

  /**
   * Provide a select list to choose the desired protocols.
   */
  function value_form(&$form, &$form_state) {
    $form['value']['#tree'] = TRUE;
    $form['value']['#type'] = 'fieldset';
    $time_options = $this->options['time_options'];
    $options = _rrdtool_time_options($time_options);
    $form['value']['start'] = array(
      '#type' => 'select',
      '#title' => t('Start'),
      '#default_value' => $this->value['start'],
      '#options' => $options,
    );
    $form['value']['end'] = array(
      '#type' => 'select',
      '#title' => t('End'),
      '#default_value' => $this->value['end'],
      '#options' => array('now' => t('Now')) + $options,
    );
    $form['startend_views_field'] = array(
      '#type' => 'value',
      '#value' => isset($this->options['expose']['identifier']) ? $this->options['expose']['identifier'] : '',
    );
  }  

  function query() {}

  function exposed_submit($form, $form_state) {
    rrdtool_cck_start_time_submit($form, $form_state);
  }
}

